==> WinBinder-0.30.101.tgz: Code/tests/test_values.php <==
<?php

//----------------------------------------------------------------- DEPENDENCIES

include_once("../inc/winbinder.php");

//-------------------------------------------------------------------- CONSTANTS

define("RTF_FMT", "{\\rtf1\\ansi\\ansicpg1252\\deff0\\deflang1033{\\fonttbl{\\f0\\fswiss\\fcharset0 Arial;}{\\f1\\fscript\\fprq2\\fcharset0 Times New Roman;}}{\\colortbl ;\\red128\\green0\\blue0;}\\viewkind4\\uc1\\pard\\cf1\\b\\f0\\fs20 Hello\\cf0\\b0 ,\\pard\\fi568  %s. \\i0\\f1\\par This text is fixed\\f0 .\\par}");

//-------------------------------------------------------------------- FUNCTIONS

function test_values($window)
{
//	wb_set_value(wb_get_control($window, IDC_SLIDER4011),		50, 0, 200);
//	wb_set_value(wb_get_control($window, IDC_PROGRESSBAR4007),	50, 0, 400);
	wb_set_value(wb_get_control($window, IDC_HSCROLL4026),		50, 0, 10000);
	wb_set_value(wb_get_control($window, IDC_UPDOWN4028),		10, 0, 50);
	wb_set_value(wb_get_control($window, IDC_CHECKBOX4034), 	TRUE);
	wb_set_value(wb_get_control($window, IDC_RADIOBUTTON4015),	TRUE);
	wb_set_value(wb_get_control($window, IDC_HSCROLL4056),	0, 0, 400);

	// List boxes / combo boxes

	wb_set_text(wb_get_control($window, IDC_LISTBOX4053),
		"Option1\nOption2\nOption3");
	wb_set_text(wb_get_control($window, IDC_COMBOBOX4054),
		"Option1\nOption2\nOption3");
	wb_set_text(wb_get_control($window, IDC_LISTBOX4055),
		"Option1\nOption2\nOption3");

	// Rich text

	wb_set_text(wb_get_control($window, IDC_RICHEDIT4061), sprintf(RTF_FMT, "This is a string from inside the source code"));
	wb_set_text(wb_get_control($window, IDC_RICHEDIT4062), file_get_contents("sample.rtf"));

	// Edit_boxes

	$text = wb_get_text(wb_get_control($window, IDC_EDIT4057));
	wb_set_text(wb_get_control($window, IDC_EDIT4058), $text);
	wb_set_text(wb_get_control($window, IDC_EDIT4059), $text);
	wb_set_text(wb_get_control($window, IDC_EDIT4065), implode(" ", array_fill(0, 20, $text)));
}

// Window handler

function process_test_values($window, $id, $lparam)
{
	$ctrl = @wb_get_control($window, $id);

	switch($id) {

		case IDC_EDIT4057:
			$text = wb_get_text(wb_get_control($window, IDC_EDIT4057));
			wb_set_text(wb_get_control($window, IDC_EDIT4058), $text);
			wb_set_text(wb_get_control($window, IDC_EDIT4059), $text);
			wb_set_text(wb_get_control($window, IDC_RICHEDIT4061), sprintf(RTF_FMT, $text));
			wb_set_text(wb_get_control($window, IDC_EDIT4065), implode(" ", array_fill(0, 20, $text)));
			break;

		case IDC_HSCROLL4056:
			break;

		case IDC_LISTBOX4053:
			if($lparam == WBC_DBLCLICK)
				wb_set_text(wb_get_control($window, IDC_STATIC4048), "Double-click");
			else
				wb_set_text(wb_get_control($window, IDC_STATIC4048), "Single click");
			break;

		case IDC_SLIDER4011:
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_value(wb_get_control($window, IDC_PROGRESSBAR4007), $value);
			wb_set_text(wb_get_control($window, IDC_STATIC4019), $value);
			wb_set_value(wb_get_control($window, IDC_HSCROLL4026), $value);
			wb_set_value(wb_get_control($window, IDC_VSCROLL4051), $value);
			wb_set_value(wb_get_control($window, IDC_UPDOWN4028), $value);
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048), "Control #$id: value [$value]\n");
			wb_set_value(wb_get_control($window, IDC_EDIT4052), $value);
			break;

		case IDC_RADIOBUTTON4014:
		case IDC_RADIOBUTTON4015:
		case IDC_RADIOBUTTON4016:
			$value = $id - IDC_RADIOBUTTON4014;
			wb_set_value(wb_get_control($window, IDC_LISTBOX4053), $value);
			wb_set_value(wb_get_control($window, IDC_COMBOBOX4054), $value);
			wb_set_value(wb_get_control($window, IDC_LISTBOX4055), $value);
			break;

		case IDC_CHECKBOX4034:
			wb_set_value(wb_get_control($window, IDC_CHECKBOX4049),
				wb_get_value(wb_get_control($window, $id)));
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048),
				"Control #$id: value [$value]\n");
			break;

		case IDC_UPDOWN4028:
		case IDC_CHECKBOX4049:
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048),
				"Control #$id: value [$value]\n");
			break;
	}
}

//-------------------------------------------------------------------------- END

?>

==> WinBinder-0.31.104.tgz: Code/tests/test_values.php <==
<?php

//----------------------------------------------------------------- DEPENDENCIES

include_once("../inc/winbinder.php");

//-------------------------------------------------------------------- CONSTANTS

define("RTF_FMT", "{\\rtf1\\ansi\\ansicpg1252\\deff0\\deflang1033{\\fonttbl{\\f0\\fswiss\\fcharset0 Arial;}{\\f1\\fscript\\fprq2\\fcharset0 Times New Roman;}}{\\colortbl ;\\red128\\green0\\blue0;}\\viewkind4\\uc1\\pard\\cf1\\b\\f0\\fs20 Hello\\cf0\\b0 ,\\pard\\fi568  %s. \\i0\\f1\\par This text is fixed\\f0 .\\par}");

//-------------------------------------------------------------------- FUNCTIONS

function test_values($window)
{
//	wb_set_value(wb_get_control($window, IDC_SLIDER4011),		20, 0, 200);
//	wb_set_value(wb_get_control($window, IDC_PROGRESSBAR4007),	null, 0, 400);
	wb_set_value(wb_get_control($window, IDC_HSCROLL4026),		50, 0, 10000);
	wb_set_value(wb_get_control($window, IDC_UPDOWN4028),		10, 0, 50);
	wb_set_value(wb_get_control($window, IDC_CHECKBOX4034), 	TRUE);
	wb_set_value(wb_get_control($window, IDC_RADIOBUTTON4015),	TRUE);
	wb_set_value(wb_get_control($window, IDC_HSCROLL4056),	0, 0, 400);

	// List boxes / combo boxes

	wb_set_text(wb_get_control($window, IDC_LISTBOX4053),
		"Option1\nOption2\nOption3");
	wb_set_text(wb_get_control($window, IDC_COMBOBOX4054),
		"Option1\nOption2\nOption3");
	wb_set_text(wb_get_control($window, IDC_LISTBOX4055),
		"Option1\nOption2\nOption3");

	// Rich text

	wb_set_text(wb_get_control($window, IDC_RICHEDIT4061), sprintf(RTF_FMT, "This is a string from inside the source code"));
	wb_set_text(wb_get_control($window, IDC_RICHEDIT4062), file_get_contents("sample.rtf"));

	// Edit_boxes

	$text = wb_get_text(wb_get_control($window, IDC_EDIT4057));
	wb_set_text(wb_get_control($window, IDC_EDIT4058), $text);
	wb_set_text(wb_get_control($window, IDC_EDIT4059), $text);
	wb_set_text(wb_get_control($window, IDC_EDIT4065), implode(" ", array_fill(0, 20, $text)));
}

// Window handler

function process_test_values($window, $id, $ctrl=0, $lparam=0)
{
//	$ctrl = @wb_get_control($window, $id);

	if($lparam == WBC_GETFOCUS) {
		wb_set_text(wb_get_control($window, IDC_STATIC4048), "Focus to control $id");
		return false;
	}

	switch($id) {

		case IDC_EDIT4057:
			$text = wb_get_text(wb_get_control($window, IDC_EDIT4057));
			wb_set_text(wb_get_control($window, IDC_EDIT4058), $text);
			wb_set_text(wb_get_control($window, IDC_EDIT4059), $text);
			wb_set_text(wb_get_control($window, IDC_RICHEDIT4061), sprintf(RTF_FMT, $text));
			wb_set_text(wb_get_control($window, IDC_EDIT4065), implode(" ", array_fill(0, 20, $text)));
			break;

		case IDC_LISTBOX4053:
			if($lparam == WBC_DBLCLICK)
				wb_set_text(wb_get_control($window, IDC_STATIC4048), "Double-click");
			else
				wb_set_text(wb_get_control($window, IDC_STATIC4048), "Single click");
			break;

		case IDC_HSCROLL4056:
		case IDC_SLIDER4011:
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_value(wb_get_control($window, IDC_PROGRESSBAR4007), $value);
			wb_set_text(wb_get_control($window, IDC_STATIC4019), $value);
			wb_set_value(wb_get_control($window, IDC_HSCROLL4026), $value);
			wb_set_value(wb_get_control($window, IDC_VSCROLL4051), $value);
			wb_set_value(wb_get_control($window, IDC_UPDOWN4028), $value);
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048), "Control #$id: value [$value]\n");
			wb_set_value(wb_get_control($window, IDC_EDIT4052), $value);
			break;

		case IDC_RADIOBUTTON4014:
		case IDC_RADIOBUTTON4015:
		case IDC_RADIOBUTTON4016:
			$value = $id - IDC_RADIOBUTTON4014;
			wb_set_value(wb_get_control($window, IDC_LISTBOX4053), $value);
			wb_set_value(wb_get_control($window, IDC_COMBOBOX4054), $value);
			wb_set_value(wb_get_control($window, IDC_LISTBOX4055), $value);
			break;

		case IDC_CHECKBOX4034:
			wb_set_value(wb_get_control($window, IDC_CHECKBOX4049),
				wb_get_value(wb_get_control($window, $id)));
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048),
				"Control #$id: value [$value]\n");
			break;

		case IDC_UPDOWN4028:
		case IDC_CHECKBOX4049:
			$value = wb_get_value(wb_get_control($window, $id));
			wb_set_text(wb_get_control($window, IDC_STATIC4048),
				"Control #$id: value [$value]\n");
			break;
	}
}

//-------------------------------------------------------------------------- END

?>
